import { ListPage } from '../models/ListPage';
import { Searchable } from '../models/Searchable';
import { Sortable } from '../models/Sortable';
import { Filters } from '../models/Filters';
import { CostCenter } from '../models/CostCenter';
import { CostCenterAssignment } from '../models/CostCenterAssignment';
import { PartialDeep } from '../models/PartialDeep';
import { RequiredDeep } from '../models/RequiredDeep';
import { RequestOptions } from '../models/RequestOptions';
declare class CostCenters {
    private impersonating;
    /**
    * @ignore
    * not part of public api, don't include in generated docs
    */
    constructor();
    /**
     * Get a list of cost centers.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/cost-centers/list|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param listOptions.search Word or phrase to search for.
     * @param listOptions.searchOn Comma-delimited list of fields to search on.
     * @param listOptions.sortBy Comma-delimited list of fields to sort by.
     * @param listOptions.page Page of results to return. Default: 1. When paginating through many items (> page 30), we recommend the "Last ID" method, as outlined in the Advanced Querying documentation.
     * @param listOptions.pageSize Number of results to return per page. Default: 20, max: 100.
     * @param listOptions.filters An object or dictionary representing key/value pairs to apply as filters. Valid keys are top-level properties of the returned model or 'xp.???'
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    List<TCostCenter extends CostCenter>(buyerID: string, listOptions?: {
        search?: string;
        searchOn?: Searchable<'CostCenters.List'>;
        sortBy?: Sortable<'CostCenters.List'>;
        page?: number;
        pageSize?: number;
        filters?: Filters;
    }, requestOptions?: RequestOptions): Promise<RequiredDeep<ListPage<TCostCenter>>>;
    /**
     * Create a new cost center. If ID is provided and an object with that ID already exists, a 409 (conflict) error is returned.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/cost-centers/create|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param costCenter Required fields: Name
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Create<TCostCenter extends CostCenter>(buyerID: string, costCenter: CostCenter, requestOptions?: RequestOptions): Promise<RequiredDeep<TCostCenter>>;
    /**
     * Get a single cost center.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/cost-centers/get|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param costCenterID ID of the cost center.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Get<TCostCenter extends CostCenter>(buyerID: string, costCenterID: string, requestOptions?: RequestOptions): Promise<RequiredDeep<TCostCenter>>;
    /**
     * Create or update a cost center. If an object with the same ID already exists, it will be overwritten.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/cost-centers/save|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param costCenterID ID of the cost center.
     * @param costCenter Required fields: Name
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Save<TCostCenter extends CostCenter>(buyerID: string, costCenterID: string, costCenter: CostCenter, requestOptions?: RequestOptions): Promise<RequiredDeep<TCostCenter>>;
    /**
     * Delete a cost center.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/cost-centers/delete|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param costCenterID ID of the cost center.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Delete(buyerID: string, costCenterID: string, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update a cost center.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/cost-centers/patch|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param costCenterID ID of the cost center.
     * @param costCenter
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Patch<TCostCenter extends CostCenter>(buyerID: string, costCenterID: string, costCenter: PartialDeep<CostCenter>, requestOptions?: RequestOptions): Promise<RequiredDeep<TCostCenter>>;
    /**
     * Delete a cost center assignment.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/cost-centers/delete-assignment|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param costCenterID ID of the cost center.
     * @param listOptions.userID ID of the user.
     * @param listOptions.userGroupID ID of the user group.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    DeleteAssignment(buyerID: string, costCenterID: string, listOptions?: {
        userID?: string;
        userGroupID?: string;
    }, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Get a list of cost center assignments.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/cost-centers/list-assignments|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param listOptions.costCenterID ID of the cost center.
     * @param listOptions.userGroupID ID of the user group.
     * @param listOptions.level Level of the cost center assignment. Possible values: Group, Company.
     * @param listOptions.page Page of results to return. Default: 1. When paginating through many items (> page 30), we recommend the "Last ID" method, as outlined in the Advanced Querying documentation.
     * @param listOptions.pageSize Number of results to return per page. Default: 20, max: 100.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    ListAssignments<TCostCenterAssignment extends CostCenterAssignment>(buyerID: string, listOptions?: {
        costCenterID?: string;
        userGroupID?: string;
        level?: 'Group' | 'Company';
        page?: number;
        pageSize?: number;
    }, requestOptions?: RequestOptions): Promise<RequiredDeep<ListPage<TCostCenterAssignment>>>;
    /**
     * Create or update a cost center assignment.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/cost-centers/save-assignment|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param costCenterAssignment Required fields: CostCenterID
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SaveAssignment(buyerID: string, costCenterAssignment: CostCenterAssignment, requestOptions?: RequestOptions): Promise<void>;
    /**
     * @description
     * enables impersonation by calling the subsequent method with the stored impersonation token
     *
     * @example
     * CostCenters.As().List() // lists CostCenters using the impersonated users' token
     */
    As(): this;
}
declare const _default: CostCenters;
export default _default;
