import { ListPage } from '../models/ListPage';
import { Searchable } from '../models/Searchable';
import { Sortable } from '../models/Sortable';
import { Filters } from '../models/Filters';
import { Locale } from '../models/Locale';
import { LocaleAssignment } from '../models/LocaleAssignment';
import { PartialDeep } from '../models/PartialDeep';
import { RequiredDeep } from '../models/RequiredDeep';
import { RequestOptions } from '../models/RequestOptions';
declare class Locales {
    private impersonating;
    /**
    * @ignore
    * not part of public api, don't include in generated docs
    */
    constructor();
    /**
     * Get a list of locales.
     * Check out the {@link https://ordercloud.io/api-reference/seller/locales/list|api docs} for more info
     *
     * @param listOptions.search Word or phrase to search for.
     * @param listOptions.searchOn Comma-delimited list of fields to search on.
     * @param listOptions.sortBy Comma-delimited list of fields to sort by.
     * @param listOptions.page Page of results to return. Default: 1. When paginating through many items (> page 30), we recommend the "Last ID" method, as outlined in the Advanced Querying documentation.
     * @param listOptions.pageSize Number of results to return per page. Default: 20, max: 100.
     * @param listOptions.filters An object or dictionary representing key/value pairs to apply as filters. Valid keys are top-level properties of the returned model or 'xp.???'
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    List<TLocale extends Locale>(listOptions?: {
        search?: string;
        searchOn?: Searchable<'Locales.List'>;
        sortBy?: Sortable<'Locales.List'>;
        page?: number;
        pageSize?: number;
        filters?: Filters;
    }, requestOptions?: RequestOptions): Promise<RequiredDeep<ListPage<TLocale>>>;
    /**
     * Create a new locale. If ID is provided and an object with that ID already exists, a 409 (conflict) error is returned.
     * Check out the {@link https://ordercloud.io/api-reference/seller/locales/create|api docs} for more info
     *
     * @param locale Required fields: Currency
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Create<TLocale extends Locale>(locale: Locale, requestOptions?: RequestOptions): Promise<RequiredDeep<TLocale>>;
    /**
     * Get a single locale.
     * Check out the {@link https://ordercloud.io/api-reference/seller/locales/get|api docs} for more info
     *
     * @param localeID ID of the locale.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Get<TLocale extends Locale>(localeID: string, requestOptions?: RequestOptions): Promise<RequiredDeep<TLocale>>;
    /**
     * Create or update a locale. If an object with the same ID already exists, it will be overwritten.
     * Check out the {@link https://ordercloud.io/api-reference/seller/locales/save|api docs} for more info
     *
     * @param localeID ID of the locale.
     * @param locale Required fields: Currency
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Save<TLocale extends Locale>(localeID: string, locale: Locale, requestOptions?: RequestOptions): Promise<RequiredDeep<TLocale>>;
    /**
     * Delete a locale.
     * Check out the {@link https://ordercloud.io/api-reference/seller/locales/delete|api docs} for more info
     *
     * @param localeID ID of the locale.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Delete(localeID: string, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update a locale.
     * Check out the {@link https://ordercloud.io/api-reference/seller/locales/patch|api docs} for more info
     *
     * @param localeID ID of the locale.
     * @param locale
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Patch<TLocale extends Locale>(localeID: string, locale: PartialDeep<Locale>, requestOptions?: RequestOptions): Promise<RequiredDeep<TLocale>>;
    /**
     * Delete a locale assignment.
     * Check out the {@link https://ordercloud.io/api-reference/seller/locales/delete-assignment|api docs} for more info
     *
     * @param localeID ID of the locale.
     * @param listOptions.buyerID ID of the buyer.
     * @param listOptions.userID ID of the user.
     * @param listOptions.userGroupID ID of the user group.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    DeleteAssignment(localeID: string, listOptions?: {
        buyerID?: string;
        userID?: string;
        userGroupID?: string;
    }, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Get a list of locale assignments.
     * Check out the {@link https://ordercloud.io/api-reference/seller/locales/list-assignments|api docs} for more info
     *
     * @param listOptions.buyerID ID of the buyer.
     * @param listOptions.localeID ID of the locale.
     * @param listOptions.userGroupID ID of the user group.
     * @param listOptions.level Level of the locale assignment. Possible values: Group, Company.
     * @param listOptions.page Page of results to return. Default: 1. When paginating through many items (> page 30), we recommend the "Last ID" method, as outlined in the Advanced Querying documentation.
     * @param listOptions.pageSize Number of results to return per page. Default: 20, max: 100.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    ListAssignments<TLocaleAssignment extends LocaleAssignment>(listOptions?: {
        buyerID?: string;
        localeID?: string;
        userGroupID?: string;
        level?: 'Group' | 'Company';
        page?: number;
        pageSize?: number;
    }, requestOptions?: RequestOptions): Promise<RequiredDeep<ListPage<TLocaleAssignment>>>;
    /**
     * Create or update a locale assignment. Do not assign a user multiple groups with different assigned locales. That is considered a misconfiguration, and will yield unexpected results.
     * Check out the {@link https://ordercloud.io/api-reference/seller/locales/save-assignment|api docs} for more info
     *
     * @param localeAssignment Required fields: LocaleID, BuyerID
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SaveAssignment(localeAssignment: LocaleAssignment, requestOptions?: RequestOptions): Promise<void>;
    /**
     * @description
     * enables impersonation by calling the subsequent method with the stored impersonation token
     *
     * @example
     * Locales.As().List() // lists Locales using the impersonated users' token
     */
    As(): this;
}
declare const _default: Locales;
export default _default;
