import { ListPage } from '../models/ListPage';
import { Searchable } from '../models/Searchable';
import { Sortable } from '../models/Sortable';
import { Filters } from '../models/Filters';
import { UserGroup } from '../models/UserGroup';
import { UserGroupAssignment } from '../models/UserGroupAssignment';
import { PartialDeep } from '../models/PartialDeep';
import { RequiredDeep } from '../models/RequiredDeep';
import { RequestOptions } from '../models/RequestOptions';
declare class SupplierUserGroups {
    private impersonating;
    /**
    * @ignore
    * not part of public api, don't include in generated docs
    */
    constructor();
    /**
     * Get a list of supplier user groups.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/supplier-user-groups/list|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param listOptions.search Word or phrase to search for.
     * @param listOptions.searchOn Comma-delimited list of fields to search on.
     * @param listOptions.sortBy Comma-delimited list of fields to sort by.
     * @param listOptions.page Page of results to return. Default: 1. When paginating through many items (> page 30), we recommend the "Last ID" method, as outlined in the Advanced Querying documentation.
     * @param listOptions.pageSize Number of results to return per page. Default: 20, max: 100.
     * @param listOptions.filters An object or dictionary representing key/value pairs to apply as filters. Valid keys are top-level properties of the returned model or 'xp.???'
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    List<TUserGroup extends UserGroup>(supplierID: string, listOptions?: {
        search?: string;
        searchOn?: Searchable<'SupplierUserGroups.List'>;
        sortBy?: Sortable<'SupplierUserGroups.List'>;
        page?: number;
        pageSize?: number;
        filters?: Filters;
    }, requestOptions?: RequestOptions): Promise<RequiredDeep<ListPage<TUserGroup>>>;
    /**
     * Create a new supplier user group. If ID is provided and an object with that ID already exists, a 409 (conflict) error is returned.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/supplier-user-groups/create|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param userGroup Required fields: Name
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Create<TUserGroup extends UserGroup>(supplierID: string, userGroup: UserGroup, requestOptions?: RequestOptions): Promise<RequiredDeep<TUserGroup>>;
    /**
     * Get a single supplier user group.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/supplier-user-groups/get|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param userGroupID ID of the user group.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Get<TUserGroup extends UserGroup>(supplierID: string, userGroupID: string, requestOptions?: RequestOptions): Promise<RequiredDeep<TUserGroup>>;
    /**
     * Create or update a supplier user group. If an object with the same ID already exists, it will be overwritten.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/supplier-user-groups/save|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param userGroupID ID of the user group.
     * @param userGroup Required fields: Name
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Save<TUserGroup extends UserGroup>(supplierID: string, userGroupID: string, userGroup: UserGroup, requestOptions?: RequestOptions): Promise<RequiredDeep<TUserGroup>>;
    /**
     * Delete a supplier user group.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/supplier-user-groups/delete|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param userGroupID ID of the user group.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Delete(supplierID: string, userGroupID: string, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update a supplier user group.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/supplier-user-groups/patch|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param userGroupID ID of the user group.
     * @param userGroup
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Patch<TUserGroup extends UserGroup>(supplierID: string, userGroupID: string, userGroup: PartialDeep<UserGroup>, requestOptions?: RequestOptions): Promise<RequiredDeep<TUserGroup>>;
    /**
     * Delete a supplier user group user assignment.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/supplier-user-groups/delete-user-assignment|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param userGroupID ID of the user group.
     * @param userID ID of the user.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    DeleteUserAssignment(supplierID: string, userGroupID: string, userID: string, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Get a list of supplier user group user assignments.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/supplier-user-groups/list-user-assignments|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param listOptions.userGroupID ID of the user group.
     * @param listOptions.userID ID of the user.
     * @param listOptions.page Page of results to return. Default: 1. When paginating through many items (> page 30), we recommend the "Last ID" method, as outlined in the Advanced Querying documentation.
     * @param listOptions.pageSize Number of results to return per page. Default: 20, max: 100.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    ListUserAssignments<TUserGroupAssignment extends UserGroupAssignment>(supplierID: string, listOptions?: {
        userGroupID?: string;
        userID?: string;
        page?: number;
        pageSize?: number;
    }, requestOptions?: RequestOptions): Promise<RequiredDeep<ListPage<TUserGroupAssignment>>>;
    /**
     * Create or update a supplier user group user assignment.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/supplier-user-groups/save-user-assignment|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param userGroupAssignment Required fields: UserGroupID, UserID
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SaveUserAssignment(supplierID: string, userGroupAssignment: UserGroupAssignment, requestOptions?: RequestOptions): Promise<void>;
    /**
     * @description
     * enables impersonation by calling the subsequent method with the stored impersonation token
     *
     * @example
     * SupplierUserGroups.As().List() // lists SupplierUserGroups using the impersonated users' token
     */
    As(): this;
}
declare const _default: SupplierUserGroups;
export default _default;
