import { ListPage } from '../models/ListPage';
import { Searchable } from '../models/Searchable';
import { Sortable } from '../models/Sortable';
import { Filters } from '../models/Filters';
import { User } from '../models/User';
import { PartialDeep } from '../models/PartialDeep';
import { RequiredDeep } from '../models/RequiredDeep';
import { RequestOptions } from '../models/RequestOptions';
declare class SupplierUsers {
    private impersonating;
    /**
    * @ignore
    * not part of public api, don't include in generated docs
    */
    constructor();
    /**
     * Get a list of supplier users.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/supplier-users/list|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param listOptions.userGroupID ID of the user group.
     * @param listOptions.search Word or phrase to search for.
     * @param listOptions.searchOn Comma-delimited list of fields to search on.
     * @param listOptions.sortBy Comma-delimited list of fields to sort by.
     * @param listOptions.page Page of results to return. Default: 1. When paginating through many items (> page 30), we recommend the "Last ID" method, as outlined in the Advanced Querying documentation.
     * @param listOptions.pageSize Number of results to return per page. Default: 20, max: 100.
     * @param listOptions.filters An object or dictionary representing key/value pairs to apply as filters. Valid keys are top-level properties of the returned model or 'xp.???'
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    List<TUser extends User>(supplierID: string, listOptions?: {
        userGroupID?: string;
        search?: string;
        searchOn?: Searchable<'SupplierUsers.List'>;
        sortBy?: Sortable<'SupplierUsers.List'>;
        page?: number;
        pageSize?: number;
        filters?: Filters;
    }, requestOptions?: RequestOptions): Promise<RequiredDeep<ListPage<TUser>>>;
    /**
     * Create a new supplier user. If ID is provided and an object with that ID already exists, a 409 (conflict) error is returned.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/supplier-users/create|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param user Required fields: Username, FirstName, LastName, Email, Active
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Create<TUser extends User>(supplierID: string, user: User, requestOptions?: RequestOptions): Promise<RequiredDeep<TUser>>;
    /**
     * Get a single supplier user.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/supplier-users/get|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param userID ID of the user.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Get<TUser extends User>(supplierID: string, userID: string, requestOptions?: RequestOptions): Promise<RequiredDeep<TUser>>;
    /**
     * Create or update a supplier user. If an object with the same ID already exists, it will be overwritten.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/supplier-users/save|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param userID ID of the user.
     * @param user Required fields: Username, FirstName, LastName, Email, Active
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Save<TUser extends User>(supplierID: string, userID: string, user: User, requestOptions?: RequestOptions): Promise<RequiredDeep<TUser>>;
    /**
     * Delete a supplier user.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/supplier-users/delete|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param userID ID of the user.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Delete(supplierID: string, userID: string, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update a supplier user.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/supplier-users/patch|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param userID ID of the user.
     * @param user
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Patch<TUser extends User>(supplierID: string, userID: string, user: PartialDeep<User>, requestOptions?: RequestOptions): Promise<RequiredDeep<TUser>>;
    /**
     * Revoke a user tokens. Revokes all security tokens of specified supplier user.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/supplier-users/revoke-user-tokens|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param userID ID of the user.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    RevokeUserTokens(supplierID: string, userID: string, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Unlock a user account.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/supplier-users/unlock-user-account|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param userID ID of the user.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    UnlockUserAccount(supplierID: string, userID: string, requestOptions?: RequestOptions): Promise<void>;
    /**
     * @description
     * enables impersonation by calling the subsequent method with the stored impersonation token
     *
     * @example
     * SupplierUsers.As().List() // lists SupplierUsers using the impersonated users' token
     */
    As(): this;
}
declare const _default: SupplierUsers;
export default _default;
